@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/controller.h,v 12.0 2009/06/28 20:43:12 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/controller.h,v 12.1 2014/01/02 22:26:03 jcb Exp $
  * controller.h
  * Contains type definitions etc used by the controller program.
  */
@@ -43,6 +43,6 @@ typedef struct {
 			   that's too much work, and we only really need it
 			   internally. */
 } GameExtras;
-#define gextras(g) ((GameExtras *)(g->userdata))
+#define gextras(g) ((GameExtras *)((g)->userdata))
 
 #endif /* CONTROLLER_H_INCLUDED */
