@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.1 2011/08/28 11:40:13 jcb Exp $
+/* $Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.2 2012/02/01 14:10:35 jcb Rel $
  * game.c
  * Routines for manipulating game data structures.
  */
@@ -14,7 +14,7 @@
  *                                                           *
  *************************************************************/
  
-static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.1 2011/08/28 11:40:13 jcb Exp $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/game.c,v 12.2 2012/02/01 14:10:35 jcb Rel $";
 
 #include "game.h"
 #include "sysdep.h"
@@ -67,10 +67,10 @@ Tile game_peek_tile(Game *g) {
    or ErrorTile if no wall
 */
 Tile game_draw_loose_tile(Game *g) {
-  if ( game_get_option_value(g,GODeadWall,NULL) && g->wall.dead_end == g->wall.live_end ) return ErrorTile;
+  if ( game_get_option_value(g,GODeadWall,NULL).optbool && g->wall.dead_end == g->wall.live_end ) return ErrorTile;
   /* we have a loose tile; adjust the wall */
   g->wall.dead_end--; /* end of dead wall moves back */
-  if ( game_get_option_value(g,GODeadWall,NULL) ) {
+  if ( game_get_option_value(g,GODeadWall,NULL).optbool ) {
     /* Now if we are in the !DeadWall16 (non-Millington case),
        extend the dead wall if necessary. It's OK if this
        goes past the beginning of the live wall; we'll get
@@ -78,7 +78,7 @@ Tile game_draw_loose_tile(Game *g) {
        (The alternative would be to say there has to be a washout
        now, which I don't like.)
     */
-    if ( !game_get_option_value(g,GODeadWall16,NULL)
+    if ( !game_get_option_value(g,GODeadWall16,NULL).optbool
 	 && ( g->wall.dead_end - g->wall.live_end < 13) )
       g->wall.live_end -= 2;
     /* if we're in the millington case, do nothing */
@@ -94,7 +94,7 @@ Tile game_draw_loose_tile(Game *g) {
    or ErrorTile if no wall
 */
 Tile game_peek_loose_tile(Game *g) {
-  if ( game_get_option_value(g,GODeadWall,NULL) ) {
+  if ( game_get_option_value(g,GODeadWall,NULL).optbool ) {
     if ( g->wall.dead_end == g->wall.live_end ) return ErrorTile;
   } else {
     if ( g->wall.dead_end == g->wall.live_used ) return ErrorTile;
@@ -226,16 +226,16 @@ GameOptionEntry *game_get_default_option_entry(GameOption option, char *name) {
 }
 
 /* see game.h for spec */
-void *game_get_option_value(Game *g, GameOption option, char *name)
+GameOptionValue game_get_option_value(Game *g, GameOption option, char *name)
 {
   GameOptionEntry *goe = NULL;
   if ( g ) goe = game_get_option_entry(g,option,name);
   if ( ! goe ) goe = game_get_default_option_entry(option,name);
-  if ( ! goe ) return 0;
+  if ( ! goe ) return (GameOptionValue)0;
   if ( goe->type == GOTString ) 
-    return (void *) &goe->value.optstring;
+    return (GameOptionValue) goe->value.optstring;
   else
-    return (void *) goe->value.optint;
+    return (GameOptionValue) goe->value.optint;
 }
 
 
@@ -317,7 +317,7 @@ int game_handle_cmsg(Game *g, CMsgMsg *cm)
   affected_id = 0;
 
   mjspecflags = 0;
-  if ( (int)game_get_option_value(g,GOSevenPairs,NULL) )
+  if ( game_get_option_value(g,GOSevenPairs,NULL).optbool )
     mjspecflags |= MJSevenPairs;
 
   switch ( cm->type ) {
@@ -513,10 +513,10 @@ int game_handle_cmsg(Game *g, CMsgMsg *cm)
       g->flags = 0;
       g->konging = NotKonging;
       g->wall.live_used = 0;
-      g->wall.size = game_get_option_value(g,GOFlowers,NULL) ? 144 : 136;
+      g->wall.size = game_get_option_value(g,GOFlowers,NULL).optbool ? 144 : 136;
       g->wall.dead_end = g->wall.size;
       g->wall.live_end = g->wall.dead_end - 
-	(game_get_option_value(g,GODeadWall,NULL) ? (game_get_option_value(g,GODeadWall16,NULL) ? 16 : 14) : 0) ;
+	(game_get_option_value(g,GODeadWall,NULL).optbool ? (game_get_option_value(g,GODeadWall16,NULL).optbool ? 16 : 14) : 0) ;
       g->serial = 0; /* must be initialized */
       for ( i = 0 ; i < MaxTile ; i++ ) {
 	g->exposed_tile_count[i] = 0;
@@ -740,7 +740,7 @@ int game_handle_cmsg(Game *g, CMsgMsg *cm)
 	  g->cmsg_err = "Don't have that special";
 	  return -1;
 	}
-	if ( game_get_option_value(g,GOFlowersLoose,NULL) )
+	if ( game_get_option_value(g,GOFlowersLoose,NULL).optbool )
 	  g->needs = FromLoose;
 	else
 	  g->needs = FromWall;
