@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.0 2009/06/28 20:43:12 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.2 2014/01/03 14:18:15 jcb Exp $
  * greedy.c
  * This is a computer player. Currently offensive only.
  * Options not documented.
@@ -15,7 +15,7 @@
  *                                                           *
  *************************************************************/
  
-static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.0 2009/06/28 20:43:12 jcb Rel $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/greedy.c,v 12.2 2014/01/03 14:18:15 jcb Exp $";
 
 static int debugeval = 0;
 #include <stdlib.h>
@@ -217,7 +217,7 @@ int main(int argc, char *argv[]) {
 	}
       }
     } else {
-      fprintf(stderr,argv[i]);
+      fprintf(stderr,"unknown option or argument: %s\n",argv[i]);
       usage(argv[0],"unknown option or argument");
     }
   }
@@ -457,7 +457,7 @@ static void do_something(void) {
   MJSpecialHandFlags mjspecflags;
 
   mjspecflags = 0;
-  if ( game_get_option_value(the_game,GOSevenPairs,NULL) )
+  if ( game_get_option_value(the_game,GOSevenPairs,NULL).optbool )
     mjspecflags |= MJSevenPairs;
 
   /* if the game is paused, and we haven't said we're ready, say so */
@@ -657,7 +657,7 @@ static void check_discard(PlayerP p, strategy *strat,int closedkong) {
   MJSpecialHandFlags mjspecflags;
 
   mjspecflags = 0;
-  if ( game_get_option_value(the_game,GOSevenPairs,NULL) )
+  if ( game_get_option_value(the_game,GOSevenPairs,NULL).optbool )
     mjspecflags |= MJSevenPairs;
 
   if ( the_game->state == Discarding 
@@ -1245,7 +1245,7 @@ static double eval(Tile *tp,strategy *strat,double *stratpoints,
       sprintf(tb,"(%4.1f) ",mval);
       strncpy(&totbuf[11*(reclevel-1)+4],tb,7);
     }
-    else fprintf(debugf,totbuf);
+    else fputs(totbuf,debugf);
   }
   return mval;
 }
@@ -1376,7 +1376,7 @@ static int chances_to_win(PlayerP p) {
   MJSpecialHandFlags mjspecflags;
 
   mjspecflags = 0;
-  if ( game_get_option_value(the_game,GOSevenPairs,NULL) )
+  if ( game_get_option_value(the_game,GOSevenPairs,NULL).optbool )
     mjspecflags |= MJSevenPairs;
 
   t = HiddenTile;
