@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/gui.h,v 12.0 2009/06/28 20:43:12 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/gui.h,v 12.7 2020/05/23 10:07:46 jcb Exp $
  * gui.h
  * type defns and forward declarations for the gui module.
  */
@@ -109,6 +109,7 @@ typedef struct _PlayerDisp {
   /* This is the window for pung! claims etc. */
   GtkWidget *claimw;
   GtkWidget *claimlab; /* and the label inside it */
+  GtkWidget *thinkbox; /* and the box holding the ... for thinking */
   int claim_serial; /* the discard for which this window was popped up */
   int claim_time; /* time popped up (in millisecs since start of program) */
 
@@ -263,6 +264,7 @@ void prefs_updater_callback(GtkWidget *w, gpointer data);
 int read_or_update_rcfile(char *rcfile,
   XmjrcGroup read_groups,
   XmjrcGroup update_groups);
+void scorehistory_init(void);
 void scoring_dialog_init(void);
 void scoring_dialog_popup(void);
 void set_dialog_posn(DialogPosition p);
@@ -287,7 +289,9 @@ void warning_clear(void);
 
 /* VARIABLES */
 
-/* in gui.c */
+extern const char *windnames[];
+extern const char *shortwindnames[];
+
 extern int debug;
 extern int server_pversion; /* protocol version that server speaks
 			       (independently of game) */
@@ -310,6 +314,12 @@ extern int game_over; /* if the game is over, but we're waiting for the user
 			 not close our connection when the other end closes.
 		      */
 
+extern int closed_set_in_progress; /* Set when the user clicks a button 
+				      to declare a closed set in scoring.
+				      Cleared by the receipt of a 
+				      FormClosed... message, or by an Error
+				      message. */
+
 extern GdkPixmap **tilepixmaps[]; /* pixmaps for the tiles */
 
 extern GtkWidget *topwindow; /* main window */
@@ -370,8 +380,13 @@ extern GtkWidget *textpages[5];
 extern GtkWidget *textlabels[5]; /* labels for the pages */
 extern GtkWidget *textwindow; /* and the window for it */
 
+/* a window for keeping the score history */
+extern GtkWidget *scorehistorywindow;
+extern GtkWidget *scorehistorytext;
+
 /* option stuff */
 extern char robot_names[3][128];
+extern char robot_options[3][128];
 
 /* The window for messages, and the display text widget */
 extern GtkWidget *messagewindow, *messagetext;
@@ -403,12 +418,15 @@ extern char table_colour_name[]; /* colour of the table background */
 extern int animate; /* do fancy animation */
 extern int nopopups; /* suppress automatic popup of message/scoring windows */
 extern int tiletips; /* show tiletips constantly */
+extern int rotatelabels; /* rotate player info labels on table */
 extern int showwall; /* show the wall or not */
 extern int sort_tiles; /* when to sort tiles */
 extern int info_windows_in_main; /* should the message and game info windows
 				    be included in the main window, or
 				    be separate popups ? */
 extern int iconify_dialogs_with_main; /* as it says ... */
+extern int thinking_claim; /* show ... before players have noclaimed */
+extern int alert_mahjong; /* pop up notice when can mahjong */
 extern char *tileset, *tileset_path; /* tile sets */
 extern int pref_showwall; /* preferred value of showwall */
 
