@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/scoring.c,v 12.0 2009/06/28 20:43:13 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/scoring.c,v 12.1 2012/02/01 14:10:22 jcb Rel $
  * scoring.c 
  * This file contains the routines to handle the scoring
  * of hands.
@@ -15,7 +15,7 @@
  *                                                           *
  *************************************************************/
 
-static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/scoring.c,v 12.0 2009/06/28 20:43:13 jcb Rel $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/scoring.c,v 12.1 2012/02/01 14:10:22 jcb Rel $";
 
 #include "tiles.h"
 #include "player.h"
@@ -67,7 +67,7 @@ static int score_of_tileset(Game *g, TileSetP tp, TileWind own, TileWind prevail
     n = 8*d;
     /* if we are using Millington's kong rules, we should distinguish
        claimed and annexed kongs here */
-    if ( game_get_option_value(g,GOKongHas3Types,NULL) ) {
+    if ( game_get_option_value(g,GOKongHas3Types,NULL).optbool ) {
       if ( tp->annexed )
 	strcat(tmp,"annexed kong of ");
       else
@@ -135,11 +135,11 @@ Score score_of_hand(Game *g, seats s) {
   p = g->players[s];
   assert(g->state == MahJonging);
 
-  limit = (int)game_get_option_value(g,GOScoreLimit,NULL);
-  nolimit = (int)game_get_option_value(g,GONoLimit,NULL);
+  limit = game_get_option_value(g,GOScoreLimit,NULL).optnat;
+  nolimit = game_get_option_value(g,GONoLimit,NULL).optnat;
 
   mjspecflags = 0;
-  if ( game_get_option_value(g,GOSevenPairs,NULL) )
+  if ( game_get_option_value(g,GOSevenPairs,NULL).optbool )
     mjspecflags |= MJSevenPairs;
 
   buf[0] = 0;
@@ -208,7 +208,7 @@ Score score_of_hand(Game *g, seats s) {
   /* Basic points */
   winner = 0;
   if ( s == g->player ) {
-    doscore("basic",(int)game_get_option_value(g,GOMahJongScore,NULL),
+    doscore("basic",game_get_option_value(g,GOMahJongScore,NULL).optscore,
 	    "going Mah Jong");
     winner = 1;
   }
@@ -242,7 +242,7 @@ Score score_of_hand(Game *g, seats s) {
       numkongs++ ;
       /* in Millington's rules, a claimed kong counts as a closed
 	 kong for doubling purposes */
-      if ( game_get_option_value(g,GOKongHas3Types,NULL)
+      if ( game_get_option_value(g,GOKongHas3Types,NULL).optbool
 	&& ! t->annexed ) {
 	numclosedpks++;
       } else {
@@ -354,7 +354,7 @@ Score score_of_hand(Game *g, seats s) {
 
   /* if we have seven pairs, give the base points */
   if ( numpairs == 7 ) {
-    doscore("basic points",(int)game_get_option_value(g,GOSevenPairsVal,NULL),"seven pairs");
+    doscore("basic points",game_get_option_value(g,GOSevenPairsVal,NULL).optscore,"seven pairs");
     noscore = 0;
   }
 
@@ -456,19 +456,19 @@ Score score_of_hand(Game *g, seats s) {
       }
     }
     if ( ownflower ) 
-      doscore("",(int)game_get_option_value(g,GOFlowersOwnEach,NULL),
+      doscore("",game_get_option_value(g,GOFlowersOwnEach,NULL).optscore,
 	      "own flower");
     if ( ownseason ) 
-      doscore("",(int)game_get_option_value(g,GOFlowersOwnEach,NULL),
+      doscore("",game_get_option_value(g,GOFlowersOwnEach,NULL).optscore,
 	      "own season");
     if ( ownflower && ownseason ) 
-      doscore("",(int)game_get_option_value(g,GOFlowersOwnBoth,NULL),
+      doscore("",game_get_option_value(g,GOFlowersOwnBoth,NULL).optscore,
 	      "own flower and season");
     if ( numflowers == 4 ) 
-      doscore("",(int)game_get_option_value(g,GOFlowersBouquet,NULL),
+      doscore("",game_get_option_value(g,GOFlowersBouquet,NULL).optscore,
 	      "all four flowers");
     if ( numseasons == 4 ) 
-      doscore("",(int)game_get_option_value(g,GOFlowersBouquet,NULL),
+      doscore("",game_get_option_value(g,GOFlowersBouquet,NULL).optscore,
 	      "all four seasons");
   }
 
@@ -500,7 +500,7 @@ Score score_of_hand(Game *g, seats s) {
     if ( noscore ) dbl(1,"no score hand");
   }
   /* some losers want these doubles to apply to losing hands also */
-  if ( winner || game_get_option_value(g,GOLosersPurity,NULL) ) {
+  if ( winner || game_get_option_value(g,GOLosersPurity,NULL).optbool ) {
     if ( allhonours ) {
       /* This should score 2 doubles, and then get a double for
 	 all majors. However, we must be careful not to give it
@@ -522,8 +522,8 @@ Score score_of_hand(Game *g, seats s) {
     /* we may have claimed a discard for a special set */
     if ( g->whence == FromDiscard ) allclosed = 0;
     if ( allclosed ) 
-      doscore("",(int)game_get_option_value(
-		g,GOConcealedFully,NULL),"concealed hand");
+      doscore("",game_get_option_value(
+		g,GOConcealedFully,NULL).optscore,"concealed hand");
   }
   /* double for almost concealed hand. This is a pain */
   if ( winner && !allclosed ) {
@@ -550,16 +550,16 @@ Score score_of_hand(Game *g, seats s) {
       }
     }
     if ( semiclosed )
-      doscore("",(int)game_get_option_value(
-		g,GOConcealedAlmost,NULL),"almost concealed hand");
+      doscore("",game_get_option_value(
+		g,GOConcealedAlmost,NULL).optscore,"almost concealed hand");
   } else if ( !winner && allclosed 
-    && game_get_option_value(g,GOLosersPurity,NULL) ) {
-    doscore("",(int)game_get_option_value(
-	      g,GOConcealedAlmost,NULL),"almost concealed hand");
+    && game_get_option_value(g,GOLosersPurity,NULL).optbool ) {
+    doscore("",game_get_option_value(
+	      g,GOConcealedAlmost,NULL).optscore,"almost concealed hand");
   }
 
   /* we may give these to losers, if somebody really wants */
-  if ( winner || game_get_option_value(g,GOLosersPurity,NULL) ) {
+  if ( winner || game_get_option_value(g,GOLosersPurity,NULL).optbool ) {
     /* NB. If no suit tiles, then we already have all honours,
        and don't give another double! */
     if ( allbamboo || allcharacter || allcircle ) {
