@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.1 2009/07/10 14:46:14 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.3 2020/05/26 09:34:06 jcb Exp $
  * sysdep.c
  * By intention, this file contains all functions that might need
  * fiddling with to cope with different variants of Unix.
@@ -21,7 +21,7 @@
  *                                                           *
  *************************************************************/
 
-static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.1 2009/07/10 14:46:14 jcb Rel $";
+static const char rcs_id[] = "$Header: /home/jcb/MahJong/newmj/RCS/sysdep.c,v 12.3 2020/05/26 09:34:06 jcb Exp $";
 
 #include "sysdep.h"
 #include <string.h>
@@ -495,7 +495,7 @@ int plain_close_socket(SOCKET s) {
    This is the internal function implementing the next two;
    the second arg says whether the first is int or SOCKET.
 */
-static char *_get_line(int fd,int is_socket) {
+static char *_get_line(SOCKET fd,int is_socket) {
   int length,i,j;
   int offset=0;
   static char *buffer = NULL;
@@ -575,7 +575,7 @@ char *fd_get_line(int fd) {
   return _get_line(fd,0);
 }
 
-static int _put_line_aux(int fd, char* line, int length, int is_socket) {
+static int _put_line_aux(SOCKET fd, char* line, int length, int is_socket) {
   int n;
   if ( is_socket ) {
     n = skt_writer ? skt_writer((void *)fd,line,length)
@@ -650,7 +650,11 @@ int put_data(SOCKET fd, char *data, int len) {
   
   if ( len == 0 ) {
 #   ifdef WIN32
+#   ifdef XCOMPILE
+    n = shutdown(fd, SHUT_WR);
+#   else
     n = shutdown(fd, SD_SEND);
+#   endif
 #   else
     n = shutdown(fd, SHUT_WR);
 #   endif
@@ -957,8 +961,9 @@ int unlink(const char *f) {
 
 unsigned int sleep(unsigned int t) { Sleep(1000*t); return 0; }
 
+#ifndef XCOMPILE
 /* I don't think we really need submillisecond resolution ... */
 unsigned int usleep(unsigned int t) { Sleep(t/1000); return 0; }
-
+#endif
 
 #endif /* WIN32 */
