@@ -1,4 +1,4 @@
-/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.h,v 12.0 2009/06/28 20:43:13 jcb Rel $
+/* $Header: /home/jcb/MahJong/newmj/RCS/sysdep.h,v 12.2 2020/05/26 09:34:13 jcb Exp $
  * sysdep.h
  * Miscellaneous system stuff that may require attention
  * by configuration procedures.
@@ -26,6 +26,12 @@
 #define _XOPEN_SOURCE_EXTENDED 1
 #include <time.h>
 #ifdef WIN32
+// these may be missing
+#ifndef SHUT_RDWR
+#define SHUT_RD   0x00
+#define SHUT_WR   0x01
+#define SHUT_RDWR 0x02
+#endif
 #include <winsock.h>
 typedef int socklen_t;
 /* following functions don't exist in Windows, so we need to emulate them */
@@ -33,7 +39,10 @@ typedef int socklen_t;
 int gettimeofday(struct timeval *tv, void *tz);
 char *getlogin(void);
 unsigned int sleep(unsigned int t);
+// provided on modern mingw
+#ifndef XCOMPILE
 unsigned int usleep(unsigned int t);
+#endif
 int getpid(void);
 int unlink(const char *f);
 #else
@@ -47,11 +56,13 @@ int unlink(const char *f);
 
 /* In the mingw I use, these functions are missing from the headers */
 #ifdef WIN32
+#ifndef XCOMPILE
 int _snprintf(char *str, size_t n, const char *format, ...);
 int _vsnprintf(char *buffer,size_t count,const char *format,va_list argptr);
 #define snprintf _snprintf
 #define vsnprintf _vsnprintf
 #endif
+#endif
 
 /* for memset and friends */
 #include <string.h>
@@ -64,7 +75,7 @@ char * index(const char *s, int c);
 
 /* define SOCKET types so we can also work with windows */
 #ifndef WIN32
-typedef int SOCKET;
+typedef intptr_t SOCKET;
 #define INVALID_SOCKET -1
 #define closesocket close
 #endif
